stm32-metapac

Crates

git

Versions

stm32h562zg

Flavors

M2dear

Struct M2dear 

#[repr(transparent)]
pub struct M2dear(pub u32);
RAMCFG memory 2 ECC double error address register.

Tuple Fields

0: u32

Implementations



impl M2dear

pub const fn edea(&self) -> u32

ECC double error address When the ALE bit is set in the MxCR register, this field is updated with the address corresponding to the ECC double error.

pub const fn set_edea(&mut self, val: u32)

ECC double error address When the ALE bit is set in the MxCR register, this field is updated with the address corresponding to the ECC double error.